@@ -57,8 +57,7 @@ graph_attr <- function(graph, name) {
   if (missing(name)) {
     graph.attributes(graph)
   } else {
-    base::.Call("R_igraph_mybracket2", graph, 9L, 2L,
-                PACKAGE="igraph")[[as.character(name)]]
+    .Call(C_R_igraph_mybracket2, graph, 9L, 2L)[[as.character(name)]]
   }
 }
 
@@ -117,8 +116,7 @@ set_graph_attr <- function(graph, name, value) {
     stop("Not a graph object")
   }
 
-  base::.Call("R_igraph_mybracket3_set", graph, 9L, 2L, name, value,
-              PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket3_set, graph, 9L, 2L, name, value)
 }
 
 #' @export
@@ -127,8 +125,7 @@ graph.attributes <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  base::.Call("R_igraph_mybracket2_copy", graph, 9L, 2L,
-              PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_copy, graph, 9L, 2L)
 } 
 
 #' @export
@@ -142,8 +139,7 @@ graph.attributes <- function(graph) {
     stop("Value must be a named list with unique names")
   }
             
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 2L, value,
-              PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 2L, value)
 }
 
 
@@ -180,8 +176,8 @@ vertex_attr <- function(graph, name, index=V(graph)) {
       vertex.attributes(graph, index = index)
     }
   } else {
-    myattr <- base::.Call("R_igraph_mybracket2", graph, 9L, 3L,
-                          PACKAGE="igraph")[[as.character(name)]]
+    myattr <-
+      .Call(C_R_igraph_mybracket2, graph, 9L, 3L)[[as.character(name)]]
     if (! missing(index)) {
       index <- as.igraph.vs(graph, index)
       myattr <- myattr[index]
@@ -257,7 +253,7 @@ i_set_vertex_attr <- function(graph, name, index=V(graph), value,
   name <- as.character(name)
   vc <- vcount(graph)
 
-  vattrs <- base::.Call("R_igraph_mybracket2", graph, 9L, 3L, PACKAGE="igraph")
+  vattrs <- .Call(C_R_igraph_mybracket2, graph, 9L, 3L)
   if (single) {
     vattrs[[name]][[index]] <- value
   } else {
@@ -265,7 +261,7 @@ i_set_vertex_attr <- function(graph, name, index=V(graph), value,
   }
   length(vattrs[[name]]) <- vc
   
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 3L, vattrs, PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 3L, vattrs)
 }
 
 #' @export
@@ -279,12 +275,12 @@ vertex.attributes <- function(graph, index = V(graph)) {
     index <- as.igraph.vs(graph, index)
   }
 
-  res <- base::.Call("R_igraph_mybracket2_copy", graph, 9L, 3L, PACKAGE="igraph")
+  res <- .Call(C_R_igraph_mybracket2_copy, graph, 9L, 3L)
 
   if (!missing(index) &&
       (length(index) != vcount(graph) || any(index != V(graph)))) {
-    for (i in seq_along(value)) {
-      value[[i]] <- value[[i]][index]
+    for (i in seq_along(res)) {
+      res[[i]] <- res[[i]][index]
     }
   }
   res
@@ -323,8 +319,7 @@ vertex.attributes <- function(graph, index = V(graph)) {
     }
   }
 
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 3L, value,
-              PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 3L, value)
 }
 
 
@@ -358,8 +353,7 @@ edge_attr <- function(graph, name, index=E(graph)) {
   } else {
     name <- as.character(name)
     index <- as.igraph.es(graph, index)
-    myattr <- base::.Call("R_igraph_mybracket2", graph, 9L, 4L,
-                    PACKAGE="igraph")[[name]]
+    myattr <- .Call(C_R_igraph_mybracket2, graph, 9L, 4L)[[name]]
     myattr[index]
   }
 }
@@ -430,7 +424,7 @@ i_set_edge_attr <- function(graph, name, index=E(graph), value,
   if (!missing(index) && check) index <- as.igraph.es(graph, index)
   ec <- ecount(graph)
 
-  eattrs <- base::.Call("R_igraph_mybracket2", graph, 9L, 4L, PACKAGE="igraph")
+  eattrs <- .Call(C_R_igraph_mybracket2, graph, 9L, 4L)
   if (single) {
     eattrs[[name]][[index]] <- value
   } else {
@@ -438,7 +432,7 @@ i_set_edge_attr <- function(graph, name, index=E(graph), value,
   }
   length(eattrs[[name]]) <- ec
 
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 4L, eattrs, PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 4L, eattrs)
 }
 
 #' @export
@@ -452,12 +446,12 @@ edge.attributes <- function(graph, index = E(graph)) {
     index <- as.igraph.es(graph, index)
   }
 
-  res <- base::.Call("R_igraph_mybracket2_copy", graph, 9L, 4L, PACKAGE="igraph")
+  res <- .Call(C_R_igraph_mybracket2_copy, graph, 9L, 4L)
 
   if (!missing(index) &&
       (length(index) != ecount(graph) || any(index != E(graph)))) {
-    for (i in seq_along(value)) {
-      value[[i]] <- value[[i]][index]
+    for (i in seq_along(res)) {
+      res[[i]] <- res[[i]][index]
     }
   }
   res
@@ -497,8 +491,7 @@ edge.attributes <- function(graph, index = E(graph)) {
     }
   }
   
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 4L, value,
-        PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 4L, value)
 }
 
 #' List names of graph attributes
@@ -518,7 +511,7 @@ graph_attr_names <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  res <- base::.Call("R_igraph_mybracket2_names", graph, 9L, 2L, PACKAGE="igraph")
+  res <- .Call(C_R_igraph_mybracket2_names, graph, 9L, 2L)
   if (is.null(res)) { res <- character() }
   res
 }
@@ -543,7 +536,7 @@ vertex_attr_names <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  res <- base::.Call("R_igraph_mybracket2_names", graph, 9L, 3L, PACKAGE="igraph")
+  res <- .Call(C_R_igraph_mybracket2_names, graph, 9L, 3L)
                      
   if (is.null(res)) { res <- character() }
   res
@@ -568,7 +561,7 @@ edge_attr_names <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  res <- base::.Call("R_igraph_mybracket2_names", graph, 9L, 4L, PACKAGE="igraph")
+  res <- .Call(C_R_igraph_mybracket2_names, graph, 9L, 4L)
   if (is.null(res)) { res <- character() }
   res
 }
@@ -598,10 +591,10 @@ delete_graph_attr <- function(graph, name) {
     stop("No such graph attribute: ", name)
   }
 
-  gattr <- base::.Call("R_igraph_mybracket2", graph, 9L, 2L, PACKAGE="igraph")
+  gattr <- .Call(C_R_igraph_mybracket2, graph, 9L, 2L)
   gattr[[name]] <- NULL
   
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 2L, gattr, PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 2L, gattr)
 }
 
 #' Delete a vertex attribute
@@ -630,10 +623,10 @@ delete_vertex_attr <- function(graph, name) {
     stop("No such vertex attribute: ", name)
   }
 
-  vattr <- base::.Call("R_igraph_mybracket2", graph, 9L, 3L, PACKAGE="igraph")
+  vattr <- .Call(C_R_igraph_mybracket2, graph, 9L, 3L)
   vattr[[name]] <- NULL
   
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 3L, vattr, PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 3L, vattr)
 }
 
 #' Delete an edge attribute
@@ -662,10 +655,10 @@ delete_edge_attr <- function(graph, name) {
     stop("No such edge attribute: ", name)
   }
 
-  eattr <- base::.Call("R_igraph_mybracket2", graph, 9L, 4L, PACKAGE="igraph")
+  eattr <- .Call(C_R_igraph_mybracket2, graph, 9L, 4L)
   eattr[[name]] <- NULL
   
-  base::.Call("R_igraph_mybracket2_set", graph, 9L, 4L, eattr, PACKAGE="igraph")
+  .Call(C_R_igraph_mybracket2_set, graph, 9L, 4L, eattr)
 }
 
 #############
