@@ -27,15 +27,38 @@
 #' This is is generic function for creating graphs.
 #'
 #' @details
-#' TODO
+#' \code{make_} is a generic function for creating graphs.
+#' For every graph constructor in igraph that has a \code{make_} prefix,
+#' there is a corresponding function without the prefix: e.g.
+#' for \code{\link{make_ring}} there is also \code{\link{ring}}, etc.
 #'
+#' The same is true for the random graph samplers, i.e. for each
+#' constructor with a \code{sample_} prefix, there is a corresponding
+#' function without that prefix.
+#'
+#' These shorter forms can be used together with \code{make_}.
+#' The advantage of this form is that the user can specify constructor
+#' modifiers which work with all constructors. E.g. the
+#' \code{link{with_vertex_}} modifier adds vertex attributes
+#' to the newly created graphs.
+#'
+#' See the examples and the various constructor modifiers below.
 #'
 #' @param ... Parameters, see details below.
 #'
+#' @seealso simplified with_edge_ with_graph_ with_vertex_
+#'   without_loops without_multiples
 #' @export
 #' @examples
 #' r <- make_(ring(10))
 #' l <- make_(lattice(c(3, 3, 3)))
+#'
+#' r2 <- make_(ring(10), with_vertex_(color = "red", name = LETTERS[1:10]))
+#' l2 <- make_(lattice(c(3, 3, 3)), with_edge_(weight = 2))
+#'
+#' ran <- sample_(degseq(c(3,3,3,3,3,3), method = "simple"), simplified())
+#' degree(ran)
+#' is_simple(ran)
 
 make_ <- function(...) {
 
@@ -533,10 +556,9 @@ make_graph <- function(edges, ..., n = max(edges), isolates = NULL,
       }
 
       old_graph <- function(edges, n = max(edges), directed = TRUE) {
-        on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-        .Call("R_igraph_create", as.numeric(edges)-1, as.numeric(n),
-              as.logical(directed),
-              PACKAGE="igraph")
+        on.exit( .Call(C_R_igraph_finalizer) )
+        .Call(C_R_igraph_create, as.numeric(edges)-1, as.numeric(n),
+              as.logical(directed))
       }
 
       args <- list(edges, ...)
@@ -569,9 +591,8 @@ make_famous_graph <- function(name) {
 
   name <- gsub("\\s", "_", name)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_famous", as.character(name),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_famous, as.character(name))
   if (igraph_opt("add.params")) {
     res$name <- capitalize(name)
   }
@@ -631,10 +652,9 @@ make_empty_graph <- function(n=0, directed=TRUE) {
   n <- as.integer(n)
   directed <- as.logical(directed)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_empty", n, directed,
-        PACKAGE="igraph")
+  res <- .Call(C_R_igraph_empty, n, directed)
 
   res
 }
@@ -897,10 +917,9 @@ make_star <- function(n, mode=c("in", "out", "mutual", "undirected"),
   mode <- igraph.match.arg(mode)
   mode1 <- switch(mode, "out"=0, "in"=1, "undirected"=2, "mutual"=3)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_star", as.numeric(n), as.numeric(mode1),
-               as.numeric(center)-1,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_star, as.numeric(n), as.numeric(mode1),
+               as.numeric(center)-1)
   if (igraph_opt("add.params")) {
     res$name <- switch(mode, "in"="In-star", "out"="Out-star", "Star")
     res$mode <- mode
@@ -930,13 +949,12 @@ star <- function(...) constructor_spec(make_star, ...)
 #' @export
 #' @examples
 #' make_full_graph(5)
-#' str(make_full_graph(4, directed = TRUE))
+#' print_all(make_full_graph(4, directed = TRUE))
 
 make_full_graph <- function(n, directed=FALSE, loops=FALSE) {
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_full", as.numeric(n), as.logical(directed),
-               as.logical(loops),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_full, as.numeric(n), as.logical(directed),
+               as.logical(loops))
   if (igraph_opt("add.params")) {
     res$name <- "Full graph"
     res$loops <- loops
@@ -990,11 +1008,10 @@ make_lattice <- function(dimvector = NULL, length = NULL, dim = NULL,
     dimvector <- rep(length, dim)
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_lattice", as.numeric(dimvector), as.numeric(nei),
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_lattice, as.numeric(dimvector), as.numeric(nei),
                as.logical(directed), as.logical(mutual),
-               as.logical(circular),
-               PACKAGE="igraph")
+               as.logical(circular))
   if (igraph_opt("add.params")) {
     res$name <- "Lattice graph"
     res$dimvector <- dimvector
@@ -1031,14 +1048,13 @@ lattice <- function(...) constructor_spec(make_lattice, ...)
 #' @family determimistic constructors
 #' @export
 #' @examples
-#' str(make_ring(10))
-#' str(make_ring(10, directed = TRUE, mutual = TRUE))
+#' print_all(make_ring(10))
+#' print_all(make_ring(10, directed = TRUE, mutual = TRUE))
 
 make_ring <- function(n, directed=FALSE, mutual=FALSE, circular=TRUE) {
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_ring", as.numeric(n), as.logical(directed),
-               as.logical(mutual), as.logical(circular),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_ring, as.numeric(n), as.logical(directed),
+               as.logical(mutual), as.logical(circular))
   if (igraph_opt("add.params")) {
     res$name <- "Ring graph"
     res$mutual <- mutual
@@ -1082,10 +1098,9 @@ make_tree <- function(n, children=2, mode=c("out", "in", "undirected")) {
   mode <- igraph.match.arg(mode)
   mode1 <- switch(mode, "out"=0, "in"=1, "undirected"=2);
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_tree", as.numeric(n), as.numeric(children),
-               as.numeric(mode1),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_tree, as.numeric(n), as.numeric(children),
+               as.numeric(mode1))
   if (igraph_opt("add.params")) {
     res$name <- "Tree"
     res$children <- children
@@ -1134,9 +1149,8 @@ tree <- function(...) constructor_spec(make_tree, ...)
 
 graph_from_atlas <- function(n) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_atlas", as.numeric(n),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_atlas, as.numeric(n))
   if (igraph_opt("add.params")) {
     res$name <- sprintf("Graph from the Atlas #%i", n)
     res$n <- n
@@ -1145,7 +1159,7 @@ graph_from_atlas <- function(n) {
 }
 
 #' @rdname graph_from_atlas
-#'  @param ... Passed to \code{graph_from_atlas}.
+#' @param ... Passed to \code{graph_from_atlas}.
 #' @export
 
 atlas <- function(...) constructor_spec(graph_from_atlas, ...)
@@ -1180,10 +1194,9 @@ atlas <- function(...) constructor_spec(graph_from_atlas, ...)
 
 make_chordal_ring <- function(n, w) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_extended_chordal_ring", as.numeric(n),
-               as.matrix(w),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_extended_chordal_ring, as.numeric(n),
+               as.matrix(w))
   if (igraph_opt("add.params")) {
     res$name <- "Extended chordal ring"
     res$w <- w
@@ -1234,9 +1247,8 @@ make_line_graph <- function(graph) {
     stop("Not a graph object")
   }
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_line_graph", graph,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_line_graph, graph)
   if (igraph_opt("add.params")) {
     res$name <- "Line graph"
   }
@@ -1286,9 +1298,8 @@ line_graph <- function(...) constructor_spec(make_line_graph, ...)
 
 make_de_bruijn_graph <- function(m, n) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_de_bruijn", as.numeric(m), as.numeric(n),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_de_bruijn, as.numeric(m), as.numeric(n))
   if (igraph_opt("add.params")) {
     res$name <- sprintf("De-Bruijn graph %i-%i", m, n)
     res$m <- m
@@ -1335,9 +1346,8 @@ de_bruijn_graph <- function(...) constructor_spec(make_de_bruijn_graph, ...)
 #'
 make_kautz_graph <- function(m, n) {
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_kautz", as.numeric(m), as.numeric(n),
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_kautz, as.numeric(m), as.numeric(n))
   if (igraph_opt("add.params")) {
     res$name <- sprintf("Kautz graph %i-%i", m, n)
     res$m <- m
@@ -1391,9 +1401,8 @@ make_full_bipartite_graph <- function(n1, n2, directed=FALSE,
   directed <- as.logical(directed)
   mode1 <- switch(igraph.match.arg(mode), "out"=1, "in"=2, "all"=3, "total"=3)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_full_bipartite", n1, n2, as.logical(directed), mode1,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_full_bipartite, n1, n2, as.logical(directed), mode1)
   if (igraph_opt("add.params")) {
     res$graph$name <- "Full bipartite graph"
     res$n1 <- n1
@@ -1457,9 +1466,8 @@ make_bipartite_graph <- function(types, edges, directed=FALSE) {
   edges <- as.numeric(edges)-1
   directed <- as.logical(directed)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_create_bipartite", types, edges, directed,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_create_bipartite, types, edges, directed)
   set_vertex_attr(res, "type", value=types)
 }
 
@@ -1485,17 +1493,16 @@ bipartite_graph <- function(...) constructor_spec(make_bipartite_graph, ...)
 #' @family determimistic constructors
 #' @export
 #' @examples
-#' str(make_full_citation_graph(10))
+#' print_all(make_full_citation_graph(10))
 
 make_full_citation_graph <- function(n, directed=TRUE) {
   # Argument checks
   n <- as.integer(n)
   directed <- as.logical(directed)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
+  on.exit( .Call(C_R_igraph_finalizer) )
   # Function call
-  res <- .Call("R_igraph_full_citation", n, directed,
-        PACKAGE="igraph")
+  res <- .Call(C_R_igraph_full_citation, n, directed)
 
   res <- set_graph_attr(res, 'name', 'Full citation graph')
   res
