@@ -101,7 +101,7 @@ rename.attr.if.needed <- function(type, graphs, newsize=NULL, maps=NULL,
 #' V(g1)$name <- letters[1:10]
 #' g2 <- make_ring(10)
 #' V(g2)$name <- letters[11:20]
-#' str(g1 %du% g2)
+#' print_all(g1 %du% g2)
 #' @export
 
 disjoint_union <- function(...) {
@@ -113,9 +113,8 @@ disjoint_union <- function(...) {
     stop("Not a graph object")
   }
   
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_disjoint_union", graphs,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_disjoint_union, graphs)
 
   ## Graph attributes
   graph.attributes(res) <- rename.attr.if.needed("g", graphs)
@@ -216,8 +215,12 @@ disjoint_union <- function(...) {
       })
     }
     
-    on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-    res <- .Call(call, newgraphs, edgemaps, PACKAGE="igraph")
+    on.exit( .Call(C_R_igraph_finalizer) )
+    if (call == "union") {
+      res <- .Call(C_R_igraph_union, newgraphs, edgemaps)
+    } else {
+      res <- .Call(C_R_igraph_intersection, newgraphs, edgemaps)
+    }
     maps <- res$edgemaps
     res <- res$graph
 
@@ -247,8 +250,12 @@ disjoint_union <- function(...) {
       })
     }
 
-    on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-    res <- .Call(call, graphs, edgemaps, PACKAGE="igraph")
+    on.exit( .Call(C_R_igraph_finalizer) )
+    if (call == "union") {
+      res <- .Call(C_R_igraph_union, graphs, edgemaps)
+    } else {
+      res <- .Call(C_R_igraph_intersection, graphs, edgemaps)
+    }
     maps <- res$edgemaps
     res <- res$graph
 
@@ -336,10 +343,10 @@ union.default <- function(...) {
 #' net1 <- graph_from_literal(D-A:B:F:G, A-C-F-A, B-E-G-B, A-B, F-G,
 #'                   H-F:G, H-I-J)
 #' net2 <- graph_from_literal(D-A:F:Y, B-A-X-F-H-Z, F-Y)
-#' str(net1 %u% net2)
+#' print_all(net1 %u% net2)
 
 union.igraph <- function(..., byname="auto") {
-  .igraph.graph.union.or.intersection("R_igraph_union", ..., byname=byname,
+  .igraph.graph.union.or.intersection("union", ..., byname=byname,
                                       keep.all.vertices=TRUE)
 }
 
@@ -412,11 +419,11 @@ intersection <- function(...)
 #' net1 <- graph_from_literal(D-A:B:F:G, A-C-F-A, B-E-G-B, A-B, F-G,
 #'                   H-F:G, H-I-J)
 #' net2 <- graph_from_literal(D-A:F:Y, B-A-X-F-H-Z, F-Y)
-#' str(net1 %s% net2)
+#' print_all(net1 %s% net2)
 
 intersection.igraph <- function(..., byname="auto",
                                 keep.all.vertices=TRUE) {
-  .igraph.graph.union.or.intersection("R_igraph_intersection", ...,
+  .igraph.graph.union.or.intersection("intersection", ...,
                                       byname=byname,
                                       keep.all.vertices=keep.all.vertices)
 }
@@ -491,7 +498,7 @@ difference <- function(...)
 #' sstar <- make_star(6, center=6, mode="undirected")
 #' V(sstar)$name <- letters[c(1,3,5,7,9,11)]
 #' G <- wheel %m% sstar
-#' str(G)
+#' print_all(G)
 #' plot(G, layout=layout_nicely(wheel))
 
 difference.igraph <- function(big, small, byname="auto", ...) {
@@ -525,15 +532,13 @@ difference.igraph <- function(big, small, byname="auto", ...) {
     }
     big <- permute(big, perm)
 
-    on.exit(.Call("R_igraph_finalizer", PACKAGE="igraph"))
-    res <- .Call("R_igraph_difference", big, small,
-                 PACKAGE="igraph")
+    on.exit(.Call(C_R_igraph_finalizer))
+    res <- .Call(C_R_igraph_difference, big, small)
     permute(res, match(V(res)$name, bnames))
 
   } else {
-    on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-    .Call("R_igraph_difference", big, small,
-          PACKAGE="igraph")
+    on.exit( .Call(C_R_igraph_finalizer) )
+    .Call(C_R_igraph_difference, big, small)
   }
 }
 
@@ -582,9 +587,8 @@ complementer <- function(graph, loops=FALSE) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_complementer", graph, as.logical(loops),
-        PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  .Call(C_R_igraph_complementer, graph, as.logical(loops))
 }
 
 
@@ -646,8 +650,8 @@ complementer <- function(graph, loops=FALSE) {
 #' g1 <- make_ring(10)
 #' g2 <- make_star(10, mode="undirected")
 #' gc <- compose(g1, g2)
-#' str(gc)
-#' str(simplify(gc))
+#' print_all(gc)
+#' print_all(simplify(gc))
 #' 
 compose <- function(g1, g2, byname="auto") {
 
@@ -687,9 +691,8 @@ compose <- function(g1, g2, byname="auto") {
   edgemaps <- (length(edge_attr_names(g1)) != 0 ||
                length(edge_attr_names(g2)) != 0)
 
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_compose", g1, g2, edgemaps,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_compose, g1, g2, edgemaps)
   maps <- list(res$edge_map1, res$edge_map2)
   res <- res$graph
 
