@@ -1,4 +1,3 @@
-
 #   IGraph R package
 #   Copyright (C) 2003-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -20,6 +19,65 @@
 #
 ###################################################################
 
+
+
+#' Plotting of graphs
+#' 
+#' \code{plot.igraph} is able to plot graphs to any R device. It is the
+#' non-interactive companion of the \code{tkplot} function.
+#' 
+#' One convenient way to plot graphs is to plot with \code{\link{tkplot}}
+#' first, handtune the placement of the vertices, query the coordinates by the
+#' \code{\link{tk_coords}} function and use them with \code{plot} to
+#' plot the graph to any R device.
+#'
+#' @aliases plot.graph
+#' @param x The graph to plot.
+#' @param axes Logical, whether to plot axes, defaults to FALSE.
+#' @param add Logical scalar, whether to add the plot to the current device, or
+#' delete the device's current contents first.
+#' @param xlim The limits for the horizontal axis, it is unlikely that you want
+#' to modify this.
+#' @param ylim The limits for the vertical axis, it is unlikely that you want
+#' to modify this.
+#' @param mark.groups A list of vertex id vectors. It is interpreted as a set
+#' of vertex groups. Each vertex group is highlighted, by plotting a colored
+#' smoothed polygon around and \dQuote{under} it. See the arguments below to
+#' control the look of the polygons.
+#' @param mark.shape A numeric scalar or vector. Controls the smoothness of the
+#' vertex group marking polygons. This is basically the \sQuote{shape}
+#' parameter of the \code{\link[graphics]{xspline}} function, its possible
+#' values are between -1 and 1. If it is a vector, then a different value is
+#' used for the different vertex groups.
+#' @param mark.col A scalar or vector giving the colors of marking the
+#' polygons, in any format accepted by \code{\link[graphics]{xspline}}; e.g.
+#' numeric color ids, symbolic color names, or colors in RGB.
+#' @param mark.border A scalar or vector giving the colors of the borders of
+#' the vertex group marking polygons. If it is \code{NA}, then no border is
+#' drawn.
+#' @param mark.expand A numeric scalar or vector, the size of the border around
+#' the marked vertex groups. It is in the same units as the vertex sizes. If a
+#' vector is given, then different values are used for the different vertex
+#' groups.
+#' @param \dots Additional plotting parameters. See \link{igraph.plotting} for
+#' the complete list.
+#' @return Returns \code{NULL}, invisibly.
+#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
+#' @seealso \code{\link{layout}} for different layouts,
+#' \code{\link{igraph.plotting}} for the detailed description of the plotting
+#' parameters and \code{\link{tkplot}} and \code{\link{rglplot}} for other
+#' graph plotting functions.
+#' @method plot igraph
+#' @export
+#' @export plot.igraph
+#' @importFrom grDevices rainbow
+#' @importFrom graphics plot polygon text par
+#' @keywords graphs
+#' @examples
+#' 
+#' g <- ring(10)
+#' \dontrun{plot(g, layout=layout_with_kk, vertex.color="green")}
+#' 
 plot.igraph <- function(x, 
                        # SPECIFIC: #####################################
                        axes=FALSE, add=FALSE,
@@ -31,7 +89,7 @@ plot.igraph <- function(x,
                        ...) {
 
   graph <- x
-  if (!is.igraph(graph)) {
+  if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
 
@@ -58,6 +116,8 @@ plot.igraph <- function(x,
   edge.label.family  <- params("edge", "label.family")
   edge.label.cex     <- params("edge", "label.cex")
   edge.label.color   <- params("edge", "label.color")
+  elab.x             <- params("edge", "label.x")
+  elab.y             <- params("edge", "label.y")
   arrow.size         <- params("edge", "arrow.size")[1]
   arrow.width        <- params("edge", "arrow.width")[1]
   curved             <- params("edge", "curved")
@@ -74,6 +134,12 @@ plot.igraph <- function(x,
   xlab               <- params("plot", "xlab")
   ylab               <- params("plot", "ylab")
 
+  palette            <- params("plot", "palette")
+  if (!is.null(palette)) {
+    old_palette <- palette(palette)
+    on.exit(palette(old_palette), add = TRUE)
+  }
+
   # the new style parameters can't do this yet
   arrow.mode         <- i.get.arrow.mode(graph, arrow.mode)
 
@@ -82,7 +148,7 @@ plot.igraph <- function(x,
   maxv <- max(vertex.size)
   if (rescale) {
     # norm layout to (-1, 1)
-    layout <- layout.norm(layout, -1, 1, -1, 1)
+    layout <- norm_coords(layout, -1, 1, -1, 1)
     xlim <- c(xlim[1]-margin[2]-maxv, xlim[2]+margin[4]+maxv)
     ylim <- c(ylim[1]-margin[1]-maxv, ylim[2]+margin[3]+maxv)
   }
@@ -103,7 +169,7 @@ plot.igraph <- function(x,
   mark.expand <- rep(mark.expand, length=length(mark.groups))
   
   for (g in seq_along(mark.groups)) {
-    v <- mark.groups[[g]]
+    v <- V(graph)[mark.groups[[g]]]
     if (length(vertex.size)==1) {
       vs <- vertex.size
     } else {
@@ -119,13 +185,25 @@ plot.igraph <- function(x,
 
   ################################################################
   ## calculate position of arrow-heads
-  el <- get.edgelist(graph, names=FALSE)
-  loops.v <- el[,1] [ el[,1] == el[,2] ]
+  el <- as_edgelist(graph, names=FALSE)
   loops.e <- which(el[,1] == el[,2])
   nonloops.e <- which(el[,1] != el[,2])
-  loop.labels <- edge.labels[el[,1] == el[,2]]
-  edge.labels <- edge.labels[el[,1] != el[,2]]
-  el <- el[el[,1] != el[,2],,drop=FALSE]
+  loops.v <- el[,1] [loops.e]
+  loop.labels <- edge.labels[loops.e]
+  loop.labx <- if (is.null(elab.x)) {
+    rep(NA, length(loops.e))
+  } else {
+    elab.x[loops.e]
+  }
+  loop.laby <- if (is.null(elab.y)) {
+    rep(NA, length(loops.e))
+  } else {
+    elab.y[loops.e]
+  }
+  edge.labels <- edge.labels[nonloops.e]
+  elab.x <- if (is.null(elab.x)) NULL else elab.x[nonloops.e]
+  elab.y <- if (is.null(elab.y)) NULL else elab.y[nonloops.e]
+  el <- el[nonloops.e,,drop=FALSE]
 
   edge.coords <- matrix(0, nrow=nrow(el), ncol=4)
   edge.coords[,1] <- layout[,1][ el[,1] ]
@@ -193,7 +271,8 @@ plot.igraph <- function(x,
     }
     
     loop <- function(x0, y0, cx=x0, cy=y0, color, angle=0, label=NA,
-                     width=1, arr=2, lty=1, arrow.size=arrow.size, arr.w=arr.w) {
+                     width=1, arr=2, lty=1, arrow.size=arrow.size,
+                     arr.w=arr.w, lab.x, lab.y) {
 
       rad <- angle
       center <- c(cx,cy)
@@ -220,6 +299,9 @@ plot.igraph <- function(x,
         lx <- cx+r*cos(phi)
         ly <- cy+r*sin(phi)
 
+        if (!is.na(lab.x)) { lx <- lab.x }
+        if (!is.na(lab.y)) { ly <- lab.y }
+
         text(lx, ly, label, col=edge.label.color, font=edge.label.font,
              family=edge.label.family, cex=edge.label.cex)
       }
@@ -243,7 +325,8 @@ plot.igraph <- function(x,
     yy0 <- layout[loops.v,2] - sin(la) * vs
     mapply(loop, xx0, yy0,
            color=ec, angle=-la, label=loop.labels, lty=lty,
-           width=ew, arr=arr, arrow.size=asize, arr.w=arrow.width)
+           width=ew, arr=arr, arrow.size=asize, arr.w=arrow.width,
+           lab.x=loop.labx, lab.y=loop.laby)
   }
 
   ################################################################
@@ -256,32 +339,35 @@ plot.igraph <- function(x,
     if (length(arrow.size)>1) { arrow.size <- arrow.size[nonloops.e] }
     if (length(curved)>1) { curved <- curved[nonloops.e] }
     if (length(unique(arrow.mode))==1) {
-      igraph.Arrows(x0, y0, x1, y1, h.col=edge.color, sh.col=edge.color,
+      lc <-igraph.Arrows(x0, y0, x1, y1, h.col=edge.color, sh.col=edge.color,
                     sh.lwd=edge.width, h.lwd=1, open=FALSE, code=arrow.mode[1],
                     sh.lty=edge.lty, h.lty=1, size=arrow.size,
                     width=arrow.width, curved=curved)
+      lc.x <- lc$lab.x
+      lc.y <- lc$lab.y
     } else {
       ## different kinds of arrows drawn separately as 'arrows' cannot
       ## handle a vector as the 'code' argument
       curved <- rep(curved, length=ecount(graph))[nonloops.e]
+      lc.x <- lc.y <- numeric(length(curved))
       for (code in 0:3) {
         valid <- arrow.mode==code
         if (!any(valid)) { next }
         ec <- edge.color ; if (length(ec)>1) { ec <- ec[valid] }
         ew <- edge.width ; if (length(ew)>1) { ew <- ew[valid] }
         el <- edge.lty   ; if (length(el)>1) { el <- el[valid] }
-        igraph.Arrows(x0[valid], y0[valid], x1[valid], y1[valid],
+        lc <- igraph.Arrows(x0[valid], y0[valid], x1[valid], y1[valid],
                       code=code, sh.col=ec, h.col=ec, sh.lwd=ew, h.lwd=1,
                       h.lty=1, sh.lty=el, open=FALSE, size=arrow.size,
                       width=arrow.width, curved=curved[valid])
+        lc.x[valid] <- lc$lab.x
+        lc.y[valid] <- lc$lab.y
       }
     }
-    phi <- atan2(y1-y0, x1-x0)
-    r <- sqrt( (x1-x0)^2 + (y1-y0)^2 )
-    x <- x0 + 2/3*r*cos(phi)
-    y <- y0 + 2/3*r*sin(phi)
-    text(x, y, labels=edge.labels, col=edge.label.color, family=edge.label.family,
-         font=edge.label.font, cex=edge.label.cex)
+    if (!is.null(elab.x)) { lc.x <- ifelse(is.na(elab.x), lc.x, elab.x) }
+    if (!is.null(elab.y)) { lc.y <- ifelse(is.na(elab.y), lc.y, elab.y) }
+    text(lc.x, lc.y, labels=edge.labels, col=edge.label.color,
+         family=edge.label.family, font=edge.label.font, cex=edge.label.cex)
   }
   
   rm(x0, y0, x1, y1)
@@ -301,9 +387,9 @@ plot.igraph <- function(x,
   # add the labels
   par(xpd=TRUE)
   x <- layout[,1]+label.dist*cos(-label.degree)* 
-    (vertex.size+6*8*log10(nchar(labels)+1))/200
+    (vertex.size+6*8*log10(2))/200
   y <- layout[,2]+label.dist*sin(-label.degree)*
-    (vertex.size+6*8*log10(nchar(labels)+1))/200
+    (vertex.size+6*8*log10(2))/200
   if (length(label.family)==1) {
     text(x, y, labels=labels, col=label.color, family=label.family,
          font=label.font, cex=label.cex)
@@ -319,15 +405,47 @@ plot.igraph <- function(x,
   invisible(NULL)
 }
 
+
+
+#' 3D plotting of graphs with OpenGL
+#' 
+#' Using the \code{rgl} package, \code{rglplot} plots a graph in 3D. The plot
+#' can be zoomed, rotated, shifted, etc. but the coordinates of the vertices is
+#' fixed.
+#' 
+#' Note that \code{rglplot} is considered to be highly experimental. It is not
+#' very useful either. See \code{\link{igraph.plotting}} for the possible
+#' arguments.
+#' 
+#' @aliases rglplot rglplot.igraph
+#' @param x The graph to plot.
+#' @param \dots Additional arguments, see \code{\link{igraph.plotting}} for the
+#' details
+#' @return \code{NULL}, invisibly.
+#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
+#' @seealso \code{\link{igraph.plotting}}, \code{\link{plot.igraph}} for the 2D
+#' version, \code{\link{tkplot}} for interactive graph drawing in 2D.
+#' @export
+#' @keywords graphs
+#' @export
+#' @examples
+#' 
+#' \dontrun{
+#' g <- make_lattice( c(5,5,5) )
+#' coords <- layout_with_fr(g, dim=3)
+#' rglplot(g, layout=coords)
+#' }
+#' 
 rglplot        <- function(x, ...)
   UseMethod("rglplot", x)
 
+#' @method rglplot igraph
+#' @export
+
 rglplot.igraph <- function(x, ...) {
 
-  require(rgl)
-  
   graph <- x
-  if (!is.igraph(graph)) {
+  if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
 
@@ -339,12 +457,12 @@ rglplot.igraph <- function(x, ...) {
     dist <- sqrt(sum((v2-v1)^2))   # distance of the centers
 
     if (am==0) {
-      edge <- qmesh3d(c(-ew/2,-ew/2,dist,1, ew/2,-ew/2,dist,1, ew/2,ew/2,dist,1,
+      edge <- rgl::qmesh3d(c(-ew/2,-ew/2,dist,1, ew/2,-ew/2,dist,1, ew/2,ew/2,dist,1,
                         -ew/2,ew/2,dist,1,  -ew/2,-ew/2,0,1, ew/2,-ew/2,0,1,
                         ew/2,ew/2,0,1, -ew/2,ew/2,0,1),
                       c(1,2,3,4, 5,6,7,8, 1,2,6,5, 2,3,7,6, 3,4,8,7, 4,1,5,8))
     } else if (am==1) {
-      edge <- qmesh3d(c(-ew/2,-ew/2,dist,1, ew/2,-ew/2,dist,1,
+      edge <- rgl::qmesh3d(c(-ew/2,-ew/2,dist,1, ew/2,-ew/2,dist,1,
                         ew/2,ew/2,dist,1, -ew/2,ew/2,dist,1,
                         -ew/2,-ew/2,al+r1,1, ew/2,-ew/2,al+r1,1,
                         ew/2,ew/2,al+r1,1, -ew/2,ew/2,al+r1,1,
@@ -355,7 +473,7 @@ rglplot.igraph <- function(x, ...) {
                         11,12,13,13))
     } else if (am==2) {
       box <- dist-r2-al
-      edge <- qmesh3d(c(-ew/2,-ew/2,box,1, ew/2,-ew/2,box,1, ew/2,ew/2,box,1,
+      edge <- rgl::qmesh3d(c(-ew/2,-ew/2,box,1, ew/2,-ew/2,box,1, ew/2,ew/2,box,1,
                         -ew/2,ew/2,box,1,  -ew/2,-ew/2,0,1, ew/2,-ew/2,0,1,
                         ew/2,ew/2,0,1, -ew/2,ew/2,0,1,
                         -aw/2,-aw/2,box,1, aw/2,-aw/2,box,1, aw/2,aw/2,box,1,
@@ -364,7 +482,7 @@ rglplot.igraph <- function(x, ...) {
                         9,10,11,12, 9,12,13,13, 9,10,13,13, 10,11,13,13,
                         11,12,13,13))
     } else {
-      edge <- qmesh3d(c(-ew/2,-ew/2,dist-al-r2,1, ew/2,-ew/2,dist-al-r2,1,
+      edge <- rgl::qmesh3d(c(-ew/2,-ew/2,dist-al-r2,1, ew/2,-ew/2,dist-al-r2,1,
                         ew/2,ew/2,dist-al-r2,1, -ew/2,ew/2,dist-al-r2,1,
                         -ew/2,-ew/2,r1+al,1, ew/2,-ew/2,r1+al,1,
                         ew/2,ew/2,r1+al,1, -ew/2,ew/2,r1+al,1,
@@ -387,11 +505,11 @@ rglplot.igraph <- function(x, ...) {
     rot1 <- rbind(c(1,0,0),c(0,cos(psi),sin(psi)), c(0,-sin(psi),cos(psi)))
     rot2 <- rbind(c(cos(phi),sin(phi),0),c(-sin(phi),cos(phi),0), c(0,0,1))
     rot <- rot1 %*% rot2
-    edge <- transform3d(edge, rotationMatrix(matrix=rot))
-    edge <- transform3d(edge, translationMatrix(v1[1], v1[2], v1[3]))
+    edge <- rgl::transform3d(edge, rgl::rotationMatrix(matrix=rot))
+    edge <- rgl::transform3d(edge, rgl::translationMatrix(v1[1], v1[2], v1[3]))
 
     ## we are ready 
-    shade3d(edge, col=ec)
+    rgl::shade3d(edge, col=ec)
   }
   
   create.loop <- function(v, r, ec, ew, am, la, la2, as) {
@@ -403,7 +521,7 @@ rglplot.igraph <- function(x, ...) {
     gap <- wi-2*ew
 
     if (am==0) {
-      edge <- qmesh3d(c(-wi/2,-ew/2,0,1, -gap/2,-ew/2,0,1,
+      edge <- rgl::qmesh3d(c(-wi/2,-ew/2,0,1, -gap/2,-ew/2,0,1,
                         -gap/2,ew/2,0,1, -wi/2,ew/2,0,1,
                         -wi/2,-ew/2,hi-ew+r,1, -gap/2,-ew/2,hi-ew+r,1,
                         -gap/2,ew/2,hi-ew+r,1, -wi/2,ew/2,hi-ew+r,1,
@@ -421,7 +539,7 @@ rglplot.igraph <- function(x, ...) {
                         5,13,19,17, 17,18,20,19, 8,16,20,18, 6,7,15,14
                         ))
     } else if (am==1 || am==2) {
-      edge <- qmesh3d(c(-wi/2,-ew/2,r+al,1, -gap/2,-ew/2,r+al,1,
+      edge <- rgl::qmesh3d(c(-wi/2,-ew/2,r+al,1, -gap/2,-ew/2,r+al,1,
                         -gap/2,ew/2,r+al,1, -wi/2,ew/2,r+al,1,
                         -wi/2,-ew/2,hi-ew+r,1, -gap/2,-ew/2,hi-ew+r,1,
                         -gap/2,ew/2,hi-ew+r,1, -wi/2,ew/2,hi-ew+r,1,
@@ -446,7 +564,7 @@ rglplot.igraph <- function(x, ...) {
                         21,24,25,25
                         ))
     } else if (am==3) {
-      edge <- qmesh3d(c(-wi/2,-ew/2,r+al,1, -gap/2,-ew/2,r+al,1,
+      edge <- rgl::qmesh3d(c(-wi/2,-ew/2,r+al,1, -gap/2,-ew/2,r+al,1,
                         -gap/2,ew/2,r+al,1, -wi/2,ew/2,r+al,1,
                         -wi/2,-ew/2,hi-ew+r,1, -gap/2,-ew/2,hi-ew+r,1,
                         -gap/2,ew/2,hi-ew+r,1, -wi/2,ew/2,hi-ew+r,1,
@@ -481,11 +599,11 @@ rglplot.igraph <- function(x, ...) {
     rot1 <- rbind(c(1,0,0),c(0,cos(la2),sin(la2)), c(0,-sin(la2),cos(la2)))
     rot2 <- rbind(c(cos(la),sin(la),0),c(-sin(la),cos(la),0), c(0,0,1))
     rot <- rot1 %*% rot2
-    edge <- transform3d(edge, rotationMatrix(matrix=rot))
-    edge <- transform3d(edge, translationMatrix(v[1], v[2], v[3]))
+    edge <- rgl::transform3d(edge, rgl::rotationMatrix(matrix=rot))
+    edge <- rgl::transform3d(edge, rgl::translationMatrix(v[1], v[2], v[3]))
 
     ## we are ready
-    shade3d(edge, col=ec)
+    rgl::shade3d(edge, col=ec)
   }
   
   # Visual parameters
@@ -515,14 +633,14 @@ rglplot.igraph <- function(x, ...) {
   # norm layout to (-1, 1)
   if (ncol(layout)==2) { layout <- cbind(layout, 0) }
   if (rescale) {
-    layout <- layout.norm(layout, -1, 1, -1, 1, -1, 1)
+    layout <- norm_coords(layout, -1, 1, -1, 1, -1, 1)
   }
   
   # add the edges, the loops are handled separately
-  el <- get.edgelist(graph, names=FALSE)
+  el <- as_edgelist(graph, names=FALSE)
   
   # It is faster this way
-  par3d(skipRedraw=TRUE)
+  rgl::par3d(skipRedraw=TRUE)
 
   # edges first
   for (i in seq(length=nrow(el))) {
@@ -548,20 +666,20 @@ rglplot.igraph <- function(x, ...) {
       
   # add the vertices
   if (length(vertex.size)==1) { vertex.size <- rep(vertex.size, nrow(layout)) }
-  rgl.spheres(layout[,1], layout[,2], layout[,3], radius=vertex.size,
+  rgl::rgl.spheres(layout[,1], layout[,2], layout[,3], radius=vertex.size,
               col=vertex.color)
 
   # add the labels, 'l1' is a stupid workaround of a mysterious rgl bug
   labels[is.na(labels)] <- ""
   x <- layout[,1]+label.dist*cos(-label.degree)* 
-    (vertex.size+6*10*log10(nchar(labels)+1))/200
+    (vertex.size+6*10*log10(2))/200
   y <- layout[,2]+label.dist*sin(-label.degree)*
-    (vertex.size+6*10*log10(nchar(labels)+1))/200
+    (vertex.size+6*10*log10(2))/200
   z <- layout[,3]
   l1 <- labels[1]
   labels[1] <- ""
-  rgl.texts(x,y,z, labels, col=label.color, adj=0)
-  rgl.texts(c(0,x[1]), c(0,y[1]), c(0,z[1]),
+  rgl::rgl.texts(x,y,z, labels, col=label.color, adj=0)
+  rgl::rgl.texts(c(0,x[1]), c(0,y[1]), c(0,z[1]),
             c("",l1), col=c(label.color[1],label.color[1]), adj=0)
 
   edge.labels[is.na(edge.labels)] <- ""
@@ -572,12 +690,12 @@ rglplot.igraph <- function(x, ...) {
     y1 <- layout[,2][el[,2]]
     z0 <- layout[,3][el[,1]]
     z1 <- layout[,4][el[,2]]
-    rgl.texts((x0+x1)/2, (y0+y1)/2, (z0+z1)/2, edge.labels,
+    rgl::rgl.texts((x0+x1)/2, (y0+y1)/2, (z0+z1)/2, edge.labels,
               col=label.color)
   }
 
   # draw everything
-  par3d(skipRedraw=FALSE)
+  rgl::par3d(skipRedraw=FALSE)
   
   invisible(NULL)
 }
@@ -585,6 +703,8 @@ rglplot.igraph <- function(x, ...) {
 # This is taken from the IDPmisc package,
 # slightly modified: code argument added
 
+#' @importFrom graphics par xyinch segments xspline lines polygon
+
 igraph.Arrows <-
 function (x1, y1, x2, y2,
                     code=2,
@@ -635,14 +755,22 @@ function (x1, y1, x2, y2,
     x1d <- r.seg*cos(th.seg1)/uin[1]
     y1d <- r.seg*sin(th.seg1)/uin[2]
   }
-  if (is.logical(curved) && all(!curved)) {
+  if (is.logical(curved) && all(!curved) ||
+      is.numeric(curved) && all(!curved)) {
+
     segments(x1+x1d, y1+y1d, x2+x2d, y2+y2d, lwd=sh.lwd, col=sh.col, lty=sh.lty)
+    phi <- atan2(y1-y2, x1-x2)
+    r <- sqrt( (x1-x2)^2 + (y1-y2)^2 )
+    lc.x <- x2 + 2/3*r*cos(phi)
+    lc.y <- y2 + 2/3*r*sin(phi)
+
   } else {
     if (is.numeric(curved)) {
       lambda <- curved
     } else {
       lambda <- as.logical(curved) * 0.5
     }
+    lambda <- rep(lambda, length.out = length(x1))
     c.x1 <- x1+x1d
     c.y1 <- y1+y1d
     c.x2 <- x2+x2d
@@ -655,17 +783,32 @@ function (x1, y1, x2, y2,
     sh.col <- rep(sh.col, length=length(c.x1))
     sh.lty <- rep(sh.lty, length=length(c.x1))
     sh.lwd <- rep(sh.lwd, length=length(c.x1))
+    lc.x <- lc.y <- numeric(length(c.x1))
+
     for (i in seq_len(length(c.x1))) {
-      spl <- xspline(x=c(c.x1[i],spx[i],c.x2[i]),
-                     y=c(c.y1[i],spy[i],c.y2[i]), shape=1, draw=FALSE)
-      lines(spl, lwd=sh.lwd[i], col=sh.col[i], lty=sh.lty[i])
-      if (code %in% c(2,3)) {
-        x1[i] <- spl$x[3*length(spl$x)/4]
-        y1[i] <- spl$y[3*length(spl$y)/4]
-      }
-      if (code %in% c(1,3)) {
-        x2[i] <- spl$x[length(spl$x)/4]
-        y2[i] <- spl$y[length(spl$y)/4]
+      ## Straight line?
+      if (lambda[i] == 0) {
+        segments(c.x1[i], c.y1[i], c.x2[i], c.y2[i],
+                 lwd = sh.lwd[i], col = sh.col[i], lty = sh.lty[i])
+        phi <- atan2(y1[i] - y2[i], x1[i] - x2[i])
+        r <- sqrt( (x1[i] - x2[i])^2 + (y1[i] - y2[i])^2 )
+        lc.x[i] <- x2[i] + 2/3*r*cos(phi)
+        lc.y[i] <- y2[i] + 2/3*r*sin(phi)
+
+      } else {
+        spl <- xspline(x=c(c.x1[i],spx[i],c.x2[i]),
+                       y=c(c.y1[i],spy[i],c.y2[i]), shape=1, draw=FALSE)
+        lines(spl, lwd=sh.lwd[i], col=sh.col[i], lty=sh.lty[i])
+        if (code %in% c(2,3)) {
+          x1[i] <- spl$x[3*length(spl$x)/4]
+          y1[i] <- spl$y[3*length(spl$y)/4]
+        }
+        if (code %in% c(1,3)) {
+          x2[i] <- spl$x[length(spl$x)/4]
+          y2[i] <- spl$y[length(spl$y)/4]
+        }
+        lc.x[i] <- spl$x[2/3 * length(spl$x)]
+        lc.y[i] <- spl$y[2/3 * length(spl$y)]
       }
     }
   }
@@ -706,8 +849,13 @@ function (x1, y1, x2, y2,
             col = h.col, lwd=h.lwd,
             border=h.col.bo, lty=h.lty)
   }
+
+  list(lab.x=lc.x, lab.y=lc.y)
+
 } # Arrows
 
+#' @importFrom graphics xspline
+
 igraph.polygon <- function(points, vertex.size=15/200, expand.by=15/200,
                            shape=1/2, col="#ff000033", border=NA) {
 
@@ -718,7 +866,7 @@ igraph.polygon <- function(points, vertex.size=15/200, expand.by=15/200,
               cbind(points[,1], points[,2]-vertex.size-by),
               cbind(points[,1], points[,2]+vertex.size+by))
 
-  cl <- convex.hull(pp)
+  cl <- convex_hull(pp)
   xspline(cl$rescoords, shape=shape, open=FALSE, col=col, border=border)
 }
 
